==> apache-ftpserver-1.1.4-src.tar.gz: apache-ftpserver-1.1.4/src/core/src/main/java/org/apache/ftpserver/usermanager/PasswordEncryptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver.usermanager;


/**
 * Strategy used for encrypting and matching encrypted passwords.
 * The purpose is to make the password encryption possible to extend.
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public interface PasswordEncryptor {

    /**
     * Encrypts the password
     * @param password The clear text password
     * @return The encrypted password
     */
    String encrypt(String password); 

    /**
     * Matches an encrypted password with that stored
     * @param passwordToCheck The encrypted password to check
     * @param storedPassword The stored password
     * @return true if the password match
     */
    boolean matches(String passwordToCheck, String storedPassword);
    
}

==> apache-ftpserver-1.2.1-src.tar.gz: apache-ftpserver-1.2.1/src/core/src/main/java/org/apache/ftpserver/usermanager/PasswordEncryptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver.usermanager;


/**
 * Strategy used for encrypting and matching encrypted passwords.
 * The purpose is to make the password encryption possible to extend.
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public interface PasswordEncryptor {
    /**
     * Encrypts the password
     * @param password The clear text password
     * @return The encrypted password
     */
    String encrypt(String password);

    /**
     * Matches an encrypted password with that stored
     * @param passwordToCheck The encrypted password to check
     * @param storedPassword The stored password
     * @return <code>true</code> if the password match
     */
    boolean matches(String passwordToCheck, String storedPassword);
}
